@@ -3,7 +3,8 @@ from .log.logging_config import LOG_DEFAULT_CONFIG
 from .log.log import log_init,add_handlers,add_loggers,update_handlers,update_loggers,get_log_config
 from .log.jsonLog import JSONLOGFormatter
 from .log.loggers import clientLogger
-from .log.mfAdapter import mfAdapter
+from .log.mfAdapter import mfAdapter,fileNo
+
 
 __all__ = ["JSONLOGFormatter",'LOG_DEFAULT_CONFIG',"clientLogger","mfAdapter","log_init",
-           "add_handlers","add_loggers","update_handlers","update_loggers","get_log_config"]
\ No newline at end of file
+           "add_handlers","add_loggers","update_handlers","update_loggers","get_log_config","fileNo"]
